# pylint: disable-msg=C0302
"""
Module contains all service names, all settings and groups

    setting template:
        settingName:
            {
                'services'(str): 'one of POSSIBLE_SERVICE_NAMES',
                'schema'(dict): 'setting validation schema',
                'default'(dict): 'setting default values',
                'description'(str): 'setting description'
            }
"""
from configs_core.base_setting_definition import BaseSettingDefinition

from . import schemas

# ALL SERVICES
LUNA_IMAGE_STORE = "luna-image-store"
LUNA_EVENTS = "luna-events"
LUNA_FACES = "luna-faces"
LUNA_API = "luna-api"
LUNA_ADMIN = "luna-admin"
LUNA_SENDER = "luna-sender"
LUNA_TASKS = "luna-tasks"
LUNA_CONFIGURATOR = "luna-configurator"
LUNA_HANDLERS = "luna-handlers"
LUNA_PYTHON_MATCHER = "luna-python-matcher"
LUNA_PYTHON_MATCHER_PROXY = "luna-matcher-proxy"
LUNA_LICENSES = "luna-licenses"
LUNA_BACKPORT4 = "luna-backport4"
LUNA_BACKPORT3 = "luna-backport3"
LUNA_ACCOUNTS = "luna-accounts"
LUNA_REMOTE_SDK = "luna-remote-sdk"
LUNA_LAMBDA = "luna-lambda"
LUNA_LAMBDA_UNIT = "luna-lambda-unit"
LUNA_LAMBDA_TASKS_UNIT = "luna-lambda-tasks-unit"
LUNA_VIDEO_MANAGER = "luna-video-manager"
LUNA_VIDEO_AGENT = "luna-video-agent"
LUNA_STREAMS_RETRANSLATOR = "luna-streams-retranslator"

# ALL GROUPS
GROUP_LUNA_PLATFORM = "luna-platform"
GROUP_FACE_STREAM = "face-stream"
GROUP_ESTIMATORS_SETTINGS = "luna-handlers-estimators-settings"
GROUP_HTTP_SETTINGS = "http-settings"

GROUPS = [GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS]

PYTHON_SERVICES = [
    LUNA_IMAGE_STORE,
    LUNA_EVENTS,
    LUNA_FACES,
    LUNA_API,
    LUNA_ADMIN,
    LUNA_SENDER,
    LUNA_TASKS,
    LUNA_CONFIGURATOR,
    LUNA_HANDLERS,
    LUNA_PYTHON_MATCHER,
    LUNA_PYTHON_MATCHER_PROXY,
    LUNA_LICENSES,
    LUNA_BACKPORT4,
    LUNA_BACKPORT3,
    LUNA_ACCOUNTS,
    LUNA_REMOTE_SDK,
    LUNA_LAMBDA,
    LUNA_LAMBDA_UNIT,
    LUNA_LAMBDA_TASKS_UNIT,
    LUNA_VIDEO_MANAGER,
    LUNA_VIDEO_AGENT,
    LUNA_STREAMS_RETRANSLATOR,
]


POSSIBLE_SERVICE_NAMES = PYTHON_SERVICES

SETTINGS = {
    "DEFAULT_IMAGE_EXTENSION": BaseSettingDefinition(
        settingName="DEFAULT_IMAGE_EXTENSION",
        services=[LUNA_IMAGE_STORE],
        schema={"type": "string", "enum": ["jpg", "png"]},
        default="jpg",
        description="default image extension for image storing",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "STORAGE_TYPE": BaseSettingDefinition(
        settingName="STORAGE_TYPE",
        services=[LUNA_IMAGE_STORE],
        schema={"type": "string", "enum": ["LOCAL", "S3"]},
        default="LOCAL",
        description="Storage type. LOCAL - local directory, S3 - AWS S3",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "DATABASE_NUMBER": BaseSettingDefinition(
        settingName="DATABASE_NUMBER",
        services=[LUNA_FACES],
        schema={"type": "integer", "enum": [0, 1, 2]},
        default=0,
        description="database number (if 1 or 2), 0 - use one database",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "USE_MATERIAL_VIEWS": BaseSettingDefinition(
        settingName="USE_MATERIAL_VIEWS",
        services=[LUNA_FACES],
        schema={"type": "integer", "enum": [0, 1]},
        default=0,
        description="Use materialized views flag",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_FACES_DB_PING_MAX_COUNT": BaseSettingDefinition(
        settingName="LUNA_FACES_DB_PING_MAX_COUNT",
        services=[LUNA_FACES],
        schema=schemas.TYPE_INT,
        default=0,
        description="max count of database ping tries (<= 0 without ping)",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "S3": BaseSettingDefinition(
        settingName="S3",
        services=[LUNA_IMAGE_STORE],
        schema=schemas.S3_SCHEMA,
        default={
            "host": "http://localhost:7480",
            "region": "",
            "aws_public_access_key": "",
            "aws_secret_access_key": "",
            "authorization_signature": "s3v4",
            "request_timeout": 60,
            "connect_timeout": 30,
            "verify_ssl": True,
            "tagging": True,
        },
        description="AWS S3 settings",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LAMBDA_S3": BaseSettingDefinition(
        settingName="LAMBDA_S3",
        services=[LUNA_LAMBDA],
        schema=schemas.LAMBDA_S3_SCHEMA,
        default={
            "host": "http://localhost:7480",
            "region": "",
            "aws_public_access_key": "",
            "aws_secret_access_key": "",
            "authorization_signature": "s3v4",
            "request_timeout": 60,
            "connect_timeout": 30,
            "bucket": "lambda_bucket",
            "verify_ssl": True,
        },
        description="AWS S3 settings for lambda",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LOCAL_STORAGE": BaseSettingDefinition(
        settingName="LOCAL_STORAGE",
        services=[LUNA_IMAGE_STORE],
        schema=schemas.TYPE_STR,
        default="./local_storage",
        description="directory for images storing",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_EVENTS_DB": BaseSettingDefinition(
        settingName="LUNA_EVENTS_DB",
        services=[LUNA_EVENTS, LUNA_PYTHON_MATCHER, LUNA_PYTHON_MATCHER_PROXY],
        schema=schemas.DB_SCHEMA,
        default={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_events",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 10},
        },
        description="Main database for luna-events service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_CONFIGURATOR_AUTHORIZATION": BaseSettingDefinition(
        settingName="LUNA_CONFIGURATOR_AUTHORIZATION",
        services=[LUNA_CONFIGURATOR],
        schema=schemas.AUTHORIZATION,
        default={"use_authorization": False, "luna_configurator_user": "luna", "luna_configurator_pass": "lunaluna"},
        description="Authorization for luna-configurator service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_CONFIGURATOR_DB": BaseSettingDefinition(
        settingName="LUNA_CONFIGURATOR_DB",
        services=[LUNA_CONFIGURATOR],
        schema=schemas.DB_SCHEMA,
        default={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_configurator",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        description="Main database for luna-configurator service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "STORAGE_TIME": BaseSettingDefinition(
        settingName="STORAGE_TIME",
        services=[
            LUNA_FACES,
            LUNA_EVENTS,
            LUNA_TASKS,
            LUNA_HANDLERS,
            LUNA_PYTHON_MATCHER,
            LUNA_PYTHON_MATCHER_PROXY,
            LUNA_BACKPORT3,
            LUNA_CONFIGURATOR,
            LUNA_ACCOUNTS,
            LUNA_LAMBDA,
            LUNA_VIDEO_MANAGER,
        ],
        schema={"type": "string", "enum": ["LOCAL", "UTC"]},
        default="LOCAL",
        description="Time in which records are stored in the database",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_FACES_DB": BaseSettingDefinition(
        settingName="LUNA_FACES_DB",
        services=[LUNA_FACES, LUNA_PYTHON_MATCHER, LUNA_PYTHON_MATCHER_PROXY],
        schema=schemas.DB_SCHEMA,
        default={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_faces",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        description="Main database for luna-faces service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "DEFAULT_FACE_DESCRIPTOR_VERSION": BaseSettingDefinition(
        settingName="DEFAULT_FACE_DESCRIPTOR_VERSION",
        services=[
            LUNA_FACES,
            LUNA_EVENTS,
            LUNA_HANDLERS,
            LUNA_API,
            LUNA_PYTHON_MATCHER,
            LUNA_PYTHON_MATCHER_PROXY,
            LUNA_REMOTE_SDK,
            LUNA_VIDEO_AGENT,
        ],
        schema=schemas.TYPE_INT,
        default=65,
        description="default face descriptor version to work with",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "DEFAULT_HUMAN_DESCRIPTOR_VERSION": BaseSettingDefinition(
        settingName="DEFAULT_HUMAN_DESCRIPTOR_VERSION",
        services=[
            LUNA_HANDLERS,
            LUNA_EVENTS,
            LUNA_PYTHON_MATCHER,
            LUNA_PYTHON_MATCHER_PROXY,
            LUNA_REMOTE_SDK,
            LUNA_VIDEO_AGENT,
        ],
        schema=schemas.TYPE_INT,
        default=116,
        description="default human descriptor version to work with",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_FACES_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_FACES_ADDRESS",
        services=[
            LUNA_API,
            LUNA_ADMIN,
            LUNA_TASKS,
            LUNA_HANDLERS,
            LUNA_BACKPORT4,
            LUNA_LAMBDA_UNIT,
            LUNA_LAMBDA_TASKS_UNIT,
        ],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5030", "api_version": 3},
        description="LUNA Faces address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_MANAGER_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_MANAGER_ADDRESS",
        services=[
            LUNA_VIDEO_AGENT,
            LUNA_API,
            LUNA_ADMIN,
        ],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5230", "api_version": 2},
        description="LUNA Video manager address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_AGENT_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_ADDRESS",
        services=[LUNA_API, LUNA_ADMIN, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5240", "api_version": 2},
        description="LUNA Video agent address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_AGENT_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_TIMEOUTS",
        services=[LUNA_API, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-video-agent service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_STREAMS_RETRANSLATOR_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_STREAMS_RETRANSLATOR_ADDRESS",
        services=[LUNA_VIDEO_MANAGER, LUNA_ADMIN, LUNA_API],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5250", "api_version": 1},
        description="LUNA Streams Retranslator address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_ACCOUNTS_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_ACCOUNTS_ADDRESS",
        services=[LUNA_API, LUNA_ADMIN],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5170", "api_version": 1},
        description="LUNA Accounts address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "ALLOW_LUNA_ACCOUNT_AUTH_HEADER": BaseSettingDefinition(
        settingName="ALLOW_LUNA_ACCOUNT_AUTH_HEADER",
        services=[LUNA_API],
        schema=schemas.TYPE_BOOL,
        default=False,
        description="Whether to allow Luna-Account-Id auth header",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_EVENTS_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_EVENTS_ADDRESS",
        services=[
            LUNA_API,
            LUNA_TASKS,
            LUNA_ADMIN,
            LUNA_HANDLERS,
            LUNA_LAMBDA_UNIT,
            LUNA_LAMBDA_TASKS_UNIT,
            LUNA_VIDEO_AGENT,
        ],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5040", "api_version": 2},
        description="LUNA Events address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_TASKS_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_TASKS_ADDRESS",
        services=[LUNA_API, LUNA_ADMIN],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5050", "api_version": 2},
        description="LUNA Tasks address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_FACES_SAMPLES_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_FACES_SAMPLES_ADDRESS",
        services=[
            LUNA_ADMIN,
            LUNA_API,
            LUNA_TASKS,
            LUNA_HANDLERS,
            LUNA_REMOTE_SDK,
            LUNA_LAMBDA_UNIT,
            LUNA_LAMBDA_TASKS_UNIT,
        ],
        schema=schemas.LUNA_IMAGE_STORE_ADDRESS,
        default={"origin": "http://127.0.0.1:5020", "api_version": 1, "bucket": "visionlabs-samples"},
        description="Address of service for storing samples",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_BODIES_SAMPLES_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_BODIES_SAMPLES_ADDRESS",
        services=[
            LUNA_ADMIN,
            LUNA_API,
            LUNA_TASKS,
            LUNA_HANDLERS,
            LUNA_REMOTE_SDK,
            LUNA_LAMBDA_UNIT,
            LUNA_LAMBDA_TASKS_UNIT,
        ],
        schema=schemas.LUNA_IMAGE_STORE_ADDRESS,
        default={"origin": "http://127.0.0.1:5020", "api_version": 1, "bucket": "visionlabs-bodies-samples"},
        description="Address of service for storing bodies samples",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_TASK_RESULT_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_TASK_RESULT_ADDRESS",
        services=[LUNA_TASKS, LUNA_ADMIN, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.LUNA_IMAGE_STORE_ADDRESS,
        default={"origin": "http://127.0.0.1:5020", "api_version": 1, "bucket": "task-result"},
        description="Address of service for storing task results",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_PORTRAITS_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_PORTRAITS_ADDRESS",
        services=[LUNA_BACKPORT3],
        schema=schemas.LUNA_IMAGE_STORE_ADDRESS,
        default={"origin": "http://127.0.0.1:5020", "api_version": 1, "bucket": "portraits"},
        description="Address of service for storing task results",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_IMAGES_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_IMAGES_ADDRESS",
        services=[
            LUNA_API,
            LUNA_ADMIN,
            LUNA_TASKS,
            LUNA_HANDLERS,
            LUNA_REMOTE_SDK,
            LUNA_LAMBDA_UNIT,
            LUNA_LAMBDA_TASKS_UNIT,
            LUNA_VIDEO_AGENT,
        ],
        schema=schemas.LUNA_IMAGE_STORE_ADDRESS,
        default={"origin": "http://127.0.0.1:5020", "api_version": 1, "bucket": "visionlabs-image-origin"},
        description="Address of service for storing origin images",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_OBJECTS_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_OBJECTS_ADDRESS",
        services=[LUNA_API, LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT, LUNA_REMOTE_SDK, LUNA_VIDEO_AGENT],
        schema=schemas.LUNA_IMAGE_STORE_ADDRESS,
        default={"origin": "http://127.0.0.1:5020", "api_version": 1, "bucket": "visionlabs-objects"},
        description="Address of service for storing objects",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_REMOTE_SDK_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_ADDRESS",
        services=[LUNA_HANDLERS, LUNA_API, LUNA_ADMIN, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5220", "api_version": 1},
        description="Address of service for remote image estimation",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_LAMBDA_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_LAMBDA_ADDRESS",
        services=[LUNA_API, LUNA_ADMIN],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5210", "api_version": 1},
        description="LUNA Lambda address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_HANDLERS_DB": BaseSettingDefinition(
        settingName="LUNA_HANDLERS_DB",
        services=[LUNA_HANDLERS],
        schema=schemas.DB_SCHEMA,
        default={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_handlers",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        description="Main database for luna-api service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "REDIS_DB_ADDRESS": BaseSettingDefinition(
        settingName="REDIS_DB_ADDRESS",
        services=[LUNA_SENDER, LUNA_HANDLERS],
        schema=schemas.REDIS_DB_SCHEMA,
        default={
            "host": "127.0.0.1",
            "port": 6379,
            "user": "",
            "password": "",
            "channel": "luna-sender",
            "sentinel": {"master_name": "luna_sender_master", "sentinels": [], "user": "", "password": ""},
        },
        description="Redis database address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_ATTRIBUTES_DB": BaseSettingDefinition(
        settingName="LUNA_ATTRIBUTES_DB",
        services=[LUNA_FACES, LUNA_PYTHON_MATCHER, LUNA_PYTHON_MATCHER_PROXY],
        schema=schemas.REDIS_STORAGE_SCHEMA,
        default={
            "host": "127.0.0.1",
            "port": 6379,
            "user": "",
            "password": "",
            "sentinel": {"master_name": "luna_attributes", "sentinels": [], "user": "", "password": ""},
            "number": 0,
        },
        description="luna temporary attributes database address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_RETRANSLATOR_DB_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_RETRANSLATOR_DB_ADDRESS",
        services=[LUNA_STREAMS_RETRANSLATOR],
        schema=schemas.REDIS_STORAGE_SCHEMA,
        default={
            "host": "127.0.0.1",
            "port": 6379,
            "user": "",
            "password": "",
            "sentinel": {"master_name": "luna_retranslator", "sentinels": [], "user": "", "password": ""},
            "number": 0,
        },
        description="luna retranslator database address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_AGENT_REDIS_DB_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_REDIS_DB_ADDRESS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.REDIS_STORAGE_SCHEMA,
        default={
            "host": "127.0.0.1",
            "port": 6379,
            "user": "",
            "password": "",
            "sentinel": {"master_name": "video_task_master", "sentinels": [], "user": "", "password": ""},
            "number": 0,
        },
        description="Redis database address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    **{
        f"{serviceName.replace('-', '_').upper()}_ACTIVE_PLUGINS": BaseSettingDefinition(
            settingName=f"{serviceName.replace('-', '_').upper()}_ACTIVE_PLUGINS",
            services=[serviceName],
            schema={"type": "array", "items": schemas.TYPE_STR},
            default=[],
            description=f"list of {serviceName} active plugins",
            groups=[GROUP_LUNA_PLATFORM],
        )
        for serviceName in PYTHON_SERVICES
    },
    "LUNA_ACCOUNTS_DB": BaseSettingDefinition(
        settingName="LUNA_ACCOUNTS_DB",
        services=[LUNA_ACCOUNTS],
        schema=schemas.DB_SCHEMA,
        default={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_accounts",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        description="Main database for luna-accounts service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_TASKS_DB": BaseSettingDefinition(
        settingName="LUNA_TASKS_DB",
        services=[LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.DB_SCHEMA,
        default={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_tasks",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        description="Main database for luna-tasks service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "TASKS_TO_FACES_REQUESTS_CONCURRENCY": BaseSettingDefinition(
        settingName="TASKS_TO_FACES_REQUESTS_CONCURRENCY",
        services=[LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.TYPE_INT,
        default=5,
        description="Concurrency for requests to luna-faces",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "TASKS_TO_IMAGE_STORE_REQUESTS_CONCURRENCY": BaseSettingDefinition(
        settingName="TASKS_TO_IMAGE_STORE_REQUESTS_CONCURRENCY",
        services=[LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.TYPE_INT,
        default=100,
        description="Concurrency for requests to luna-image-store",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "MAX_ERROR_COUNT_PER_TASK": BaseSettingDefinition(
        settingName="MAX_ERROR_COUNT_PER_TASK",
        services=[LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.TYPE_INT,
        default=100_000,
        description="Maximum errors count per task to store",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_FACES_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_FACES_TIMEOUTS",
        services=[LUNA_TASKS, LUNA_API, LUNA_HANDLERS, LUNA_BACKPORT4, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-faces service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_MANAGER_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_MANAGER_TIMEOUTS",
        services=[LUNA_VIDEO_AGENT, LUNA_API],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-video-manager service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_STREAMS_RETRANSLATOR_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_STREAMS_RETRANSLATOR_TIMEOUTS",
        services=[LUNA_VIDEO_MANAGER, LUNA_API],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-streams-retranslator service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_ACCOUNTS_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_ACCOUNTS_TIMEOUTS",
        services=[LUNA_API],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-accounts service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_ADMIN_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_ADMIN_TIMEOUTS",
        services=[LUNA_ADMIN],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to other services from luna-admin",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_EVENTS_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_EVENTS_TIMEOUTS",
        services=[LUNA_TASKS, LUNA_API, LUNA_HANDLERS, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT, LUNA_VIDEO_AGENT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-events service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_FACES_SAMPLES_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_FACES_SAMPLES_TIMEOUTS",
        services=[LUNA_TASKS, LUNA_API, LUNA_HANDLERS, LUNA_REMOTE_SDK, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-image-store service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_BODIES_SAMPLES_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_BODIES_SAMPLES_TIMEOUTS",
        services=[LUNA_TASKS, LUNA_API, LUNA_HANDLERS, LUNA_REMOTE_SDK, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-image-store service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_TASK_RESULT_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_TASK_RESULT_TIMEOUTS",
        services=[LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-image-store service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_PORTRAITS_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_PORTRAITS_TIMEOUTS",
        services=[LUNA_BACKPORT3],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-image-store service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_IMAGES_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_IMAGES_TIMEOUTS",
        services=[
            LUNA_API,
            LUNA_TASKS,
            LUNA_HANDLERS,
            LUNA_REMOTE_SDK,
            LUNA_LAMBDA_UNIT,
            LUNA_LAMBDA_TASKS_UNIT,
            LUNA_VIDEO_AGENT,
        ],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-image-store service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_IMAGE_STORE_OBJECTS_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_OBJECTS_TIMEOUTS",
        services=[LUNA_API, LUNA_VIDEO_AGENT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-image-store service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_TASKS_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_TASKS_TIMEOUTS",
        services=[LUNA_API],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-tasks service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_REMOTE_SDK_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_TIMEOUTS",
        services=[LUNA_HANDLERS, LUNA_API, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-remote-sdk service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_LAMBDA_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_LAMBDA_TIMEOUTS",
        services=[LUNA_API],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-lambda service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_LAMBDA_UNIT_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_LAMBDA_UNIT_TIMEOUTS",
        services=[LUNA_HANDLERS],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to lambda unit",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_MONITORING": BaseSettingDefinition(
        settingName="LUNA_MONITORING",
        services=PYTHON_SERVICES,
        schema=schemas.LUNA_MONITORING_SCHEMA,
        default={
            "storage_type": "influx",
            "send_data_for_monitoring": 1,
            "use_ssl": 0,
            "flushing_period": 1,
            "host": "127.0.0.1",
            "port": 8086,
            "bucket": "luna_monitoring",
            "organization": "luna",
            "token": "secret-token",
        },
        description="monitoring parameters",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_TASKS_LOAD_EXTERNAL_ARCHIVE_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_TASKS_LOAD_EXTERNAL_ARCHIVE_TIMEOUTS",
        services=[LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 100, "connect": 20, "sock_connect": 10, "sock_read": 100},
        description="timeouts for http-request to external resource for download archive",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_SENDER_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_SENDER_ADDRESS",
        services=[LUNA_ADMIN, LUNA_API, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT, LUNA_VIDEO_AGENT],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5080", "api_version": 2},
        description="LUNA Sender address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_SENDER_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_SENDER_TIMEOUTS",
        services=[LUNA_VIDEO_AGENT, LUNA_API],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-sender service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_API_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_API_ADDRESS",
        services=[LUNA_VIDEO_AGENT, LUNA_ADMIN, LUNA_BACKPORT4, LUNA_BACKPORT3],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5000", "api_version": 6},
        description="LUNA API address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_API_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_API_TIMEOUTS",
        services=[LUNA_VIDEO_AGENT, LUNA_BACKPORT4, LUNA_BACKPORT3],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-api service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    **{
        f"{serviceName.replace('-', '_').upper()}_LOGGER": BaseSettingDefinition(
            settingName=f"{serviceName.replace('-', '_').upper()}_LOGGER",
            services=[serviceName],
            schema=schemas.LOGGER_SCHEMA,
            default={
                "log_level": "INFO",
                "folder_with_logs": "./",
                "max_log_file_size": 1024,
                "log_time": "LOCAL",
                "log_to_stdout": True,
                "log_to_file": False,
                "multiline_stack_trace": True,
                "format": "default",
            },
            description=f"{' '.join(map(str.capitalize, serviceName.split('-')))} logger settings",
            groups=[GROUP_LUNA_PLATFORM],
        )
        for serviceName in PYTHON_SERVICES
    },
    "ADDITIONAL_SERVICES_USAGE": BaseSettingDefinition(
        settingName="ADDITIONAL_SERVICES_USAGE",
        services=[
            LUNA_API,
            LUNA_TASKS,
            LUNA_ADMIN,
            LUNA_HANDLERS,
            LUNA_PYTHON_MATCHER,
            LUNA_PYTHON_MATCHER_PROXY,
            LUNA_REMOTE_SDK,
            LUNA_LAMBDA_UNIT,
            LUNA_LAMBDA,
            LUNA_LAMBDA_TASKS_UNIT,
            LUNA_VIDEO_AGENT,
            LUNA_VIDEO_MANAGER,
        ],
        schema=schemas.ADDITIONAL_SERVICES_USAGE,
        default={
            "luna_sender": True,
            "luna_events": True,
            "luna_faces": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
            "luna_handlers": True,
            "luna_lambda": False,
            "luna_python_matcher": True,
            "luna_remote_sdk": True,
            "luna_video_manager": False,
            "luna_video_agent": False,
            "luna_streams_retranslator": False,
        },
        description=schemas.ADDITIONAL_SERVICES_USAGE["description"],
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_CONFIGURATOR": BaseSettingDefinition(
        settingName="LUNA_CONFIGURATOR",
        services=PYTHON_SERVICES,
        schema=schemas.CONFIGURATOR_USAGE,
        default={
            "use_configurator": False,
            "luna_configurator_origin": "http://127.0.0.1:5070",
            "luna_configurator_api": 1,
            "luna_configurator_user": "",
            "luna_configurator_pass": "",
        },
        description=schemas.CONFIGURATOR_USAGE["description"],
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_REMOTE_SDK_FACE_DETECTOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_FACE_DETECTOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_FACE_DETECTOR_SETTINGS,
        default={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1},
            "estimator_settings": {
                "min_face_size": 50,
                "redetect_tensor_size": 80,
                "redetect_face_target_size": 64,
                "redetect_score_threshold": 0.5,
                "score_threshold": 0.5,
            },
        },
        description="luna-remote-sdk settings for face detector",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_GAZE_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_GAZE_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for gaze estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_QUALITY_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_QUALITY_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for quality estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_MOUTH_ATTRIBUTES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_MOUTH_ATTRIBUTES_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for mouth attributes estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_EMOTIONS_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_EMOTIONS_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for emotions estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_BASIC_ATTRIBUTES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_BASIC_ATTRIBUTES_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for basic attributes estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_EYES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_EYES_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for eyes estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_HEAD_POSE_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_HEAD_POSE_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for head pose estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_FACE_DESCRIPTOR_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_FACE_DESCRIPTOR_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for face descriptor estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_MASK_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_MASK_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for mask estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_LIVENESS_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_LIVENESS_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_LIVENESS_ESTIMATOR_SETTINGS,
        default={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1},
            "estimator_settings": {"real_threshold": 0.5},
        },
        description="luna-remote-sdk settings for liveness estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_DEEPFAKE_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_DEEPFAKE_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_DEEPFAKE_ESTIMATOR_SETTINGS,
        default={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1},
            "estimator_settings": {"real_threshold": 0.5, "estimation_mode": 2},
        },
        description="luna-remote-sdk settings for liveness estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_FACE_OCCLUSION_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_FACE_OCCLUSION_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_FACE_OCCLUSION_ESTIMATOR_SETTINGS,
        default={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1},
            "estimator_settings": {
                "occlusion_threshold": 0.07,
                "hair_threshold": 0.15,
                "forehead_threshold": 0.2,
                "eye_threshold": 0.15,
                "nose_threshold": 0.2,
                "mouth_threshold": 0.15,
                "lower_face_threshold": 0.2,
            },
        },
        description="luna-remote-sdk settings for face occlusion estimation",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_GLASSES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_GLASSES_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for glasses estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_FACE_WARP_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_FACE_WARP_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for face warp estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_FACE_LANDMARKS68_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_FACE_LANDMARKS68_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for face landmarks68 estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_FACE_LANDMARKS5_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_FACE_LANDMARKS5_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for face landmarks5 estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_IMAGE_COLOR_TYPE_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_IMAGE_COLOR_TYPE_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for image color type estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_HEADWEAR_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_HEADWEAR_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for headwear estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_FACE_NATURAL_LIGHT_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_FACE_NATURAL_LIGHT_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for face natural light estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_FISHEYE_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_FISHEYE_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for fisheye estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_EYEBROW_EXPRESSION_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_EYEBROW_EXPRESSION_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for eyebrow expression estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_RED_EYES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_RED_EYES_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for red eyes estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_FACE_DETECTION_BACKGROUND_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_FACE_DETECTION_BACKGROUND_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for face detection background estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_PORTRAIT_STYLE_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_PORTRAIT_STYLE_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for portrait style estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_IMAGE_ORIENTATION_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_IMAGE_ORIENTATION_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for image orientation estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_IMAGE_MODIFICATION_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_IMAGE_MODIFICATION_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for image modification estimation",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_BODY_DETECTOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_BODY_DETECTOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_BODY_DETECTOR_SETTINGS,
        default={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1},
            "estimator_settings": {
                "image_size": 640,
                "redetect_score_threshold": 0.12,
                "score_threshold": 0.5,
            },
        },
        description="luna-remote-sdk settings for body detection in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_BODY_DESCRIPTOR_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_BODY_DESCRIPTOR_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for body descriptor estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_BODY_WARP_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_BODY_WARP_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for body warp estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_BODY_LANDMARKS_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_BODY_LANDMARKS_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for body landmarks estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_BODY_ATTRIBUTES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_BODY_ATTRIBUTES_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for body attributes estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_HUMAN_DETECTOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_HUMAN_DETECTOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for human detection in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "FACE_QUALITY_SETTINGS": BaseSettingDefinition(
        settingName="FACE_QUALITY_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.FACE_QUALITY_SETTINGS,
        default={
            "image_format": {"threshold": ["JPEG", "JPEG2000", "PNG"]},
            "image_modification": {
                "threshold": 0,
                "config": {"estimator": {"threshold": {"max": 0.5}}},
            },
            "illumination": {"threshold": {"min": 0.3, "max": 1}},
            "specularity": {"threshold": {"min": 0.3, "max": 1}},
            "blurriness": {"threshold": {"min": 0.61, "max": 1}},
            "dark": {"threshold": {"min": 0.5, "max": 1}},
            "light": {"threshold": {"min": 0.57, "max": 1}},
            "head_yaw": {"threshold": {"min": -5, "max": 5}},
            "head_pitch": {"threshold": {"min": -5, "max": 5}},
            "head_roll": {"threshold": {"min": -8, "max": 8}},
            "gaze_yaw": {"threshold": {"min": -5, "max": 5}},
            "gaze_pitch": {"threshold": {"min": -5, "max": 5}},
            "mouth_smiling": {"threshold": {"min": 0, "max": 0.5}},
            "mouth_occluded": {"threshold": {"min": 0, "max": 0.5}},
            "mouth_open": {"threshold": {"min": 0, "max": 0.5}},
            "glasses": {"threshold": ["no_glasses", "eyeglasses"]},
            "eyes": {"threshold": ["open"]},
            "head_horizontal_center": {"threshold": {"min": 0.45, "max": 0.55}},
            "head_vertical_center": {"threshold": {"min": 0.3, "max": 0.5}},
            "head_width": {"threshold": {"min": 0.5, "max": 0.75}},
            "head_height": {"threshold": {"min": 0.6, "max": 0.9}},
            "eye_distance": {"threshold": {"min": 90}},
            "image_width": {"threshold": {"min": 180, "max": 1920}},
            "image_height": {"threshold": {"min": 180, "max": 1080}},
            "aspect_ratio": {"threshold": {"min": 0.74, "max": 0.8}},
            "face_width": {"threshold": {"min": 180}},
            "face_height": {"threshold": {"min": 180}},
            "indent_left": {"threshold": {"min": 20}},
            "indent_right": {"threshold": {"min": 20}},
            "indent_upper": {"threshold": {"min": 20}},
            "indent_lower": {"threshold": {"min": 20}},
            "image_size": {"threshold": {"min": 5 * 2**10, "max": 2048 * 2**10}},
            "illumination_uniformity": {"threshold": {"min": 0.5}},
            "dynamic_range": {"threshold": {"min": 0.5}},
            "eyebrows": {"threshold": ["neutral"]},
            "shoulders": {"threshold": ["parallel"]},
            "smile": {"threshold": ["none"]},
            "headwear": {"threshold": ["none"]},
            "natural_light": {
                "threshold": 1,
                "config": {"estimator": {"threshold": {"min": 0.5}}},
            },
            "fish_eye": {
                "threshold": 0,
                "config": {"estimator": {"threshold": {"min": 0.5}}},
            },
            "red_eye": {
                "threshold": 0,
                "config": {"estimator": {"threshold": {"min": 0.5}}},
            },
            "color_type": {
                "threshold": ["color"],
                "config": {"infrared": {"threshold": {"min": 0.5}}, "color": {"threshold": {"min": 0.5}}},
            },
            "background_lightness": {"threshold": {"min": 0.2}},
            "background_uniformity": {"threshold": {"min": 0.5}},
            "face_occlusion": {"threshold": 0},
            "lower_face_occlusion": {"threshold": 0},
            "forehead_occlusion": {"threshold": 0},
            "nose_occlusion": {"threshold": 0},
        },
        description="settings for face quality checks",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "FETCH_IMAGE_TIMEOUTS": BaseSettingDefinition(
        settingName="FETCH_IMAGE_TIMEOUTS",
        services=[LUNA_HANDLERS, LUNA_REMOTE_SDK],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 10, "connect": 10, "sock_connect": 10, "sock_read": 10},
        description="timeouts for http-request to external resource for download images",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_HANDLERS_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_HANDLERS_ADDRESS",
        services=[LUNA_API, LUNA_TASKS, LUNA_ADMIN, LUNA_LAMBDA_TASKS_UNIT, LUNA_VIDEO_AGENT, LUNA_LAMBDA_UNIT],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5090", "api_version": 1},
        description="LUNA Handlers address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_HANDLERS_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_HANDLERS_TIMEOUTS",
        services=[LUNA_API, LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT, LUNA_VIDEO_AGENT, LUNA_LAMBDA_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-handlers service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "SAVE_EVENTS_TIMEOUT": BaseSettingDefinition(
        settingName="SAVE_EVENTS_TIMEOUT",
        services=[LUNA_EVENTS],
        schema=schemas.TYPE_FLOAT,
        default=2,
        description="save events timeout. 0 or negative means no timeout",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "TASKS_TO_HANDLERS_CONCURRENCY": BaseSettingDefinition(
        settingName="TASKS_TO_HANDLERS_CONCURRENCY",
        services=[LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.TYPE_NOT_NEGATIVE_INT,
        default=8,
        description="Tasks to handlers extract request concurrency.",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "TASKS_TO_MATCHER_CONCURRENCY": BaseSettingDefinition(
        settingName="TASKS_TO_MATCHER_CONCURRENCY",
        services=[LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema={"type": "integer", "minimum": 1},
        default=2,
        description="Tasks to matcher request concurrency.",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_PYTHON_MATCHER_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_PYTHON_MATCHER_ADDRESS",
        services=[
            LUNA_API,
            LUNA_HANDLERS,
            LUNA_TASKS,
            LUNA_ADMIN,
            LUNA_PYTHON_MATCHER_PROXY,
            LUNA_LAMBDA_UNIT,
            LUNA_LAMBDA_TASKS_UNIT,
        ],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5100", "api_version": 1},
        description="LUNA Python Matcher address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_PYTHON_MATCHER_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_PYTHON_MATCHER_TIMEOUTS",
        services=[LUNA_API, LUNA_HANDLERS, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-python-matcher service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_PROXY_TO_PYTHON_MATCHER_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_PROXY_TO_PYTHON_MATCHER_TIMEOUTS",
        services=[LUNA_PYTHON_MATCHER_PROXY],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 300, "connect": 20, "sock_connect": 10, "sock_read": 300},
        description="timeouts for http-request from luna-python-matcher-proxy to luna-python-matcher service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_TASKS_TO_MATCHER_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_TASKS_TO_MATCHER_TIMEOUTS",
        services=[LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 300, "connect": 20, "sock_connect": 10, "sock_read": 300},
        description="timeouts for http-request to LUNA Matcher entry point service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_MATCHER_PROXY_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_MATCHER_PROXY_ADDRESS",
        services=[LUNA_API, LUNA_HANDLERS, LUNA_TASKS, LUNA_ADMIN, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5110", "api_version": 1},
        description="LUNA Python Matcher Proxy address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_PYTHON_MATCHER_PROXY_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_PYTHON_MATCHER_PROXY_TIMEOUTS",
        services=[LUNA_API, LUNA_HANDLERS, LUNA_LAMBDA_UNIT, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to luna-matcher-proxy service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "ATTRIBUTES_STORAGE_POLICY": BaseSettingDefinition(
        settingName="ATTRIBUTES_STORAGE_POLICY",
        services=[LUNA_FACES, LUNA_BACKPORT4, LUNA_HANDLERS],
        schema=schemas.ATTRIBUTES_STORAGE_POLICY,
        default={"default_ttl": 300, "max_ttl": 24 * 60 * 60},
        description="temporary attributes storage settings",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_LICENSES_ADDRESS": BaseSettingDefinition(
        settingName="LUNA_LICENSES_ADDRESS",
        services=[LUNA_ADMIN, LUNA_API, LUNA_FACES, LUNA_REMOTE_SDK, LUNA_LAMBDA, LUNA_VIDEO_AGENT, LUNA_VIDEO_MANAGER],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5120", "api_version": 1},
        description="LUNA Licenses address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "DESCRIPTORS_CACHE": BaseSettingDefinition(
        settingName="DESCRIPTORS_CACHE",
        services=[LUNA_PYTHON_MATCHER],
        schema=schemas.DESCRIPTORS_CACHE,
        default={
            "cache_enabled": True,
            "updating_cache_interval": 2,
            "matching_settings": {"thread_count": 0, "batch_size": 20, "tasks_count": 10},
            "rpc_settings": {
                "timeouts": {"connect_timeout": 20, "request_timeout": 60, "response_timeout": 60},
                "pool_size": 100,
            },
            "cached_data": {
                "faces_lists": {
                    "exclude": [],
                    "include": None,
                }
            },
        },
        description="LUNA Python Matcher descriptor caching settings",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_BACKPORT3_DB": BaseSettingDefinition(
        settingName="LUNA_BACKPORT3_DB",
        services=[LUNA_BACKPORT3],
        schema=schemas.DB_SCHEMA,
        default={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_backport3",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        description="Main database for luna-backport3 service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "USE_SAMPLES_AS_PORTRAITS": BaseSettingDefinition(
        settingName="USE_SAMPLES_AS_PORTRAITS",
        services=[LUNA_BACKPORT3],
        schema=schemas.TYPE_BOOL,
        default=True,
        description="use samples as portraits",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "MAX_CANDIDATE_IN_RESPONSE": BaseSettingDefinition(
        settingName="MAX_CANDIDATE_IN_RESPONSE",
        services=[LUNA_BACKPORT3],
        schema=schemas.TYPE_NATURAL,
        default=5,
        description="max candidate count into a response on matching request",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_BACKPORT3_STORE_EVENTS": BaseSettingDefinition(
        settingName="LUNA_BACKPORT3_STORE_EVENTS",
        services=[LUNA_BACKPORT3],
        schema=schemas.TYPE_BOOL,
        default=False,
        description="whether to store events",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_BACKPORT3_USE_HANDLERS": BaseSettingDefinition(
        settingName="LUNA_BACKPORT3_USE_HANDLERS",
        services=[LUNA_BACKPORT3],
        schema=schemas.TYPE_BOOL,
        default=True,
        description="whether to use handlers",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_HANDLERS_LIMITS": BaseSettingDefinition(
        settingName="LUNA_HANDLERS_LIMITS",
        services=[LUNA_HANDLERS],
        schema=schemas.LIMITS_SCHEMA,
        default={
            "received_images_limit": 8,
            "raw_event_detections_limit": 100,
            "raw_event_arrays_limit": 30,
            "result_candidate_limit": 100,
        },
        description="luna handlers limits",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_REMOTE_SDK_LIMITS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_LIMITS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.LUNA_REMOTE_SDK_LIMITS_SCHEMA,
        default={
            "received_images_limit": 8,
        },
        description="luna remote sdk limits",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "PLATFORM_LIMITS": BaseSettingDefinition(
        settingName="PLATFORM_LIMITS",
        services=[LUNA_PYTHON_MATCHER, LUNA_PYTHON_MATCHER_PROXY, LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.PLATFORM_LIMITS_SCHEMA,
        default={
            "match": {
                "array_filter_limit": 1000,
                "reference_limit": 30,
                "candidate_limit": 30,
                "result_candidate_limit": 100,
            },
            "cross_match": {
                "short_array_filter_limit": 1000,
                "array_filter_limit": 20000,
                "result_candidate_limit": 20000,
                "general_limit": 100000000,
            },
        },
        description="platform limits",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "EXTERNAL_LUNA_API_ADDRESS": BaseSettingDefinition(
        settingName="EXTERNAL_LUNA_API_ADDRESS",
        services=[LUNA_HANDLERS, LUNA_TASKS, LUNA_API, LUNA_REMOTE_SDK, LUNA_LAMBDA_TASKS_UNIT, LUNA_VIDEO_AGENT],
        schema=schemas.SERVICE_ADDRESS,
        default={"origin": "http://127.0.0.1:5000", "api_version": 6},
        description="external luna api address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "BACKPORT3_ENABLE_WS_EVENTS": BaseSettingDefinition(
        settingName="BACKPORT3_ENABLE_WS_EVENTS",
        services=[LUNA_BACKPORT3],
        schema=schemas.TYPE_BOOL,
        default=True,
        description="Whether to enable ws events support",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "BACKPORT3_ENABLE_PORTRAITS": BaseSettingDefinition(
        settingName="BACKPORT3_ENABLE_PORTRAITS",
        services=[LUNA_BACKPORT3],
        schema=schemas.TYPE_BOOL,
        default=True,
        description="Whether to enable portraits support",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "BACKPORT3_EVENTS_DB_ADDRESS": BaseSettingDefinition(
        settingName="BACKPORT3_EVENTS_DB_ADDRESS",
        services=[LUNA_BACKPORT3],
        schema=schemas.REDIS_DB_SCHEMA,
        default={
            "host": "127.0.0.1",
            "port": 6379,
            "user": "",
            "password": "",
            "channel": "luna-backport3",
            "sentinel": {"master_name": "luna_backport3_master", "sentinels": [], "user": "", "password": ""},
        },
        description="Redis database address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LICENSE_VENDOR": BaseSettingDefinition(
        settingName="LICENSE_VENDOR",
        services=[LUNA_LICENSES],
        schema=schemas.LICENSE_VENDOR,
        default={
            "vendor": "hasp",
            "server_address": "127.0.0.1",
        },
        description="License vendor config",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    **{
        f"{serviceName.replace('-', '_').upper()}_HTTP_SETTINGS": BaseSettingDefinition(
            settingName=f"{serviceName.replace('-', '_').upper()}_HTTP_SETTINGS",
            services=[serviceName],
            schema=schemas.SERVICE_HTTP_SETTINGS,
            default={
                "request_timeout": 60,
                "response_timeout": 10 * 60,
                "request_max_size": 2 ** (10 + 10 + 10),
                "keep_alive_timeout": 200,
            },
            description=f"{' '.join(map(str.capitalize, serviceName.split('-')))} http settings",
            groups=[GROUP_LUNA_PLATFORM],
        )
        for serviceName in PYTHON_SERVICES
    },
    "LUNA_IMAGE_STORE_HTTP_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_IMAGE_STORE_HTTP_SETTINGS",
        services=[LUNA_IMAGE_STORE],
        schema=schemas.SERVICE_HTTP_SETTINGS,
        default={
            "request_timeout": 60,
            "response_timeout": 10 * 60,
            "request_max_size": 2 ** (10 + 10 + 10 + 7),
            "keep_alive_timeout": 200,
        },
        description=f"{LUNA_IMAGE_STORE} http settings",
        groups=[GROUP_LUNA_PLATFORM, GROUP_HTTP_SETTINGS],
    ),
    "LUNA_API_HTTP_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_API_HTTP_SETTINGS",
        services=[LUNA_API],
        schema=schemas.SERVICE_HTTP_SETTINGS,
        default={
            "request_timeout": 60,
            "response_timeout": 10 * 60,
            "request_max_size": 2 ** (10 + 10 + 10 + 7),
            "keep_alive_timeout": 15,
        },
        description=f"{LUNA_API} http settings",
        groups=[GROUP_LUNA_PLATFORM, GROUP_HTTP_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_RUNTIME_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_RUNTIME_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.RUNTIME_SETTINGS,
        default={"global_device_class": "cpu", "num_threads": 6, "num_compute_streams": 4},
        description="runtime settings for luna-remote-sdk",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_RUNTIME_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_RUNTIME_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.RUNTIME_SETTINGS,
        default={"global_device_class": "cpu", "num_threads": 6, "num_compute_streams": 4},
        description="runtime settings for luna-video-agent",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.AGENT_SETTINGS,
        default={"max_active_streams": 2, "max_active_tasks": 2},
        description="settings for luna-video-agent",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_LIVENESS_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_LIVENESS_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_LIVENESS_ESTIMATOR_SETTINGS,
        default={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1},
            "estimator_settings": {"real_threshold": 0.5},
        },
        description="luna-video-agent settings for liveness estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_DEEPFAKE_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_DEEPFAKE_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_DEEPFAKE_ESTIMATOR_SETTINGS,
        default={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1},
            "estimator_settings": {"real_threshold": 0.5, "estimation_mode": 2},
        },
        description="luna-video-agent settings for liveness estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_HUMAN_DETECTOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_HUMAN_DETECTOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for human detection in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_PEOPLE_COUNT_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_PEOPLE_COUNT_ESTIMATOR_SETTINGS",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-remote-sdk settings for people count estimation",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_PEOPLE_COUNT_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_PEOPLE_COUNT_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for people count estimation",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_FACE_DESCRIPTOR_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_FACE_DESCRIPTOR_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for face descriptor estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_BASIC_ATTRIBUTES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_BASIC_ATTRIBUTES_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for basic attributes estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_BODY_DESCRIPTOR_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_BODY_DESCRIPTOR_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for body descriptor estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_BODY_ATTRIBUTES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_BODY_ATTRIBUTES_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for body attributes estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_EMOTIONS_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_EMOTIONS_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for emotions estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_GAZE_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_GAZE_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for gaze estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_EYES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_EYES_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for eyes estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_MASK_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_MASK_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for mask estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_GLASSES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_GLASSES_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for glasses estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_MOUTH_ATTRIBUTES_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_MOUTH_ATTRIBUTES_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for mouth attributes estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_AGS_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_AGS_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for ags estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_HUMAN_TRACKER_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_HUMAN_TRACKER_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.TE_ESTIMATOR_SETTINGS,
        default={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 100},
            "estimator_settings": {
                "detector_step": 7,
                "scale_result_size": 640,
                "skip_frames": 18,
            },
        },
        description="luna-video-agent settings for trackengine",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_DETECTOR_TYPE": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_DETECTOR_TYPE",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.DETECTOR_TYPE,
        default="FACE_DET_V3",
        description="luna-remote-sdk face detector type",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_REMOTE_SDK_USE_AUTO_ROTATION": BaseSettingDefinition(
        settingName="LUNA_REMOTE_SDK_USE_AUTO_ROTATION",
        services=[LUNA_REMOTE_SDK],
        schema=schemas.TYPE_BOOL,
        default=False,
        description="whether to try estimate image rotation angle and rotate to normal state",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_VIDEO_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_VIDEO_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.VIDEO_SETTINGS,
        default={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "frame_pool_size": 10,
            "ffmpeg_thread_count": 0,
            "max_size": 2048,
            "timeouts": {"connect": 30.0, "request": 60.0, "sock_connect": 10.0, "sock_read": 60.0},
        },
        description="luna-video-agent video processing settings",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_AGENT_FACE_WARP_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_FACE_WARP_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for face warp estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_FACE_WARP_QUALITY_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_FACE_WARP_QUALITY_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for face warp quality estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_BODY_WARP_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_BODY_WARP_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for body warp estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_FACE_LANDMARKS5_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_FACE_LANDMARKS5_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for face landmarks5 estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_VIDEO_AGENT_HEAD_POSE_ESTIMATOR_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_VIDEO_AGENT_HEAD_POSE_ESTIMATOR_SETTINGS",
        services=[LUNA_VIDEO_AGENT],
        schema=schemas.SDK_ESTIMATOR_SETTINGS,
        default={"runtime_settings": {"device_class": "global", "optimal_batch_size": 10, "worker_count": 1}},
        description="luna-video-agent settings for head pose estimation in handlers",
        groups=[GROUP_LUNA_PLATFORM, GROUP_ESTIMATORS_SETTINGS],
    ),
    "LUNA_LAMBDA_DB": BaseSettingDefinition(
        settingName="LUNA_LAMBDA_DB",
        services=[LUNA_LAMBDA],
        schema=schemas.POSTGRES_DB_SCHEMA,
        default={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_lambda",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        description="Main database for luna-lambda service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LAMBDA_REGISTRY": BaseSettingDefinition(
        settingName="LAMBDA_REGISTRY",
        services=[LUNA_LAMBDA],
        schema=schemas.TYPE_STR,
        default="registry.address",
        description="lambda registry",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LAMBDA_INSECURE_REGISTRIES": BaseSettingDefinition(
        settingName="LAMBDA_INSECURE_REGISTRIES",
        services=[LUNA_LAMBDA],
        schema={"type": "array", "items": schemas.TYPE_STR},
        default=[],
        description="user plugin insecure registries",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "CLUSTER_LOCATION": BaseSettingDefinition(
        settingName="CLUSTER_LOCATION",
        services=[LUNA_LAMBDA],
        schema=schemas.CLUSTER_LOCATION,
        default="internal",
        description="k8s cluster location: remote/local(executed on same machine)/internal(executed in cluster)",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "CLUSTER_CREDENTIALS": BaseSettingDefinition(
        settingName="CLUSTER_CREDENTIALS",
        services=[LUNA_LAMBDA],
        schema=schemas.CLUSTER_CREDENTIALS,
        default={"host": "https://127.0.0.1:6443", "token": "", "certificate_path": "cert.crt"},
        description="k8s cluster credentials",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_LAMBDA_BUILD_LIMITS": BaseSettingDefinition(
        settingName="LUNA_LAMBDA_BUILD_LIMITS",
        services=[LUNA_LAMBDA],
        schema=schemas.LUNA_LAMBDA_BUILD_LIMITS,
        default={"cpu_limit": 2000, "ram_limit": 4, "cpu_request": 500, "ram_request": 0.5},
        description="Resource requests and limits for lambda build.",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "TASKS_REDIS_DB_ADDRESS": BaseSettingDefinition(
        settingName="TASKS_REDIS_DB_ADDRESS",
        services=[LUNA_TASKS, LUNA_LAMBDA_TASKS_UNIT],
        schema=schemas.REDIS_STORAGE_SCHEMA,
        default={
            "host": "127.0.0.1",
            "port": 6379,
            "user": "",
            "password": "",
            "sentinel": {"master_name": "luna_tasks", "sentinels": [], "user": "", "password": ""},
            "number": 0,
        },
        description="Redis database address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_LAMBDA_TASKS_UNIT_TIMEOUTS": BaseSettingDefinition(
        settingName="LUNA_LAMBDA_TASKS_UNIT_TIMEOUTS",
        services=[LUNA_TASKS],
        schema=schemas.AIOHTTP_TIMEOUT,
        default={"request": 60, "connect": 20, "sock_connect": 10, "sock_read": 60},
        description="timeouts for http-request to lambda unit",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_API_PLUGINS_SETTINGS": BaseSettingDefinition(
        settingName="LUNA_API_PLUGINS_SETTINGS",
        services=[LUNA_API],
        schema=schemas.LUNA_API_PLUGINS_SETTINGS,
        default={},
        description="LUNA API plugins settings",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_SERVICE_METRICS": BaseSettingDefinition(
        settingName="LUNA_SERVICE_METRICS",
        services=PYTHON_SERVICES,
        schema=schemas.METRICS,
        default={"enabled": False, "metrics_format": "prometheus", "extra_labels": {}},
        description="Metrics collection configuration",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_MANAGER_DB": BaseSettingDefinition(
        settingName="LUNA_VIDEO_MANAGER_DB",
        services=[LUNA_VIDEO_MANAGER],
        schema=schemas.POSTGRES_DB_SCHEMA,
        default={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_video_manager",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        description="Main database for luna-video-manager service",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_MANAGER_STREAM_STATUS_OBSOLETING_PERIOD": BaseSettingDefinition(
        settingName="LUNA_VIDEO_MANAGER_STREAM_STATUS_OBSOLETING_PERIOD",
        services=[LUNA_VIDEO_MANAGER],
        schema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        default=20,
        description="video manager stream status obsoleting period, sec",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_MANAGER_STREAM_STATUS_OBSOLETING_INTERVAL": BaseSettingDefinition(
        settingName="LUNA_VIDEO_MANAGER_STREAM_STATUS_OBSOLETING_INTERVAL",
        services=[LUNA_VIDEO_MANAGER],
        schema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        default=5,
        description="video manager stream status obsoleting calculation execution interval, sec",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_MANAGER_AGENT_STATUS_OBSOLETING_PERIOD": BaseSettingDefinition(
        settingName="LUNA_VIDEO_MANAGER_AGENT_STATUS_OBSOLETING_PERIOD",
        services=[LUNA_VIDEO_MANAGER],
        schema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        default=60,
        description="video manager agent status obsoleting period, sec",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_MANAGER_AGENT_STATUS_OBSOLETING_INTERVAL": BaseSettingDefinition(
        settingName="LUNA_VIDEO_MANAGER_AGENT_STATUS_OBSOLETING_INTERVAL",
        services=[LUNA_VIDEO_MANAGER],
        schema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        default=10,
        description="video manager agent status obsoleting calculation execution interval, sec",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_MANAGER_STREAMS_AGENT_SEARCH_INTERVAL": BaseSettingDefinition(
        settingName="LUNA_VIDEO_MANAGER_STREAMS_AGENT_SEARCH_INTERVAL",
        services=[LUNA_VIDEO_MANAGER],
        schema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        default=5,
        description="video manager searching agent for streams execution interval, sec",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_MANAGER_STREAMS_AUTORESTARTER_INTERVAL": BaseSettingDefinition(
        settingName="LUNA_VIDEO_MANAGER_STREAMS_AUTORESTARTER_INTERVAL",
        services=[LUNA_VIDEO_MANAGER],
        schema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        default=5,
        description="video manager agent streams autorestarter execution interval, sec",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_STREAMS_RETRANSLATOR_IGNORED_RESTREAM_TTL": BaseSettingDefinition(
        settingName="LUNA_STREAMS_RETRANSLATOR_IGNORED_RESTREAM_TTL",
        services=[LUNA_STREAMS_RETRANSLATOR],
        schema=schemas.TYPE_INT,
        default=60,
        description="ttl of not used restream",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "DESCRIPTOR_ENCRYPTION": BaseSettingDefinition(
        settingName="DESCRIPTOR_ENCRYPTION",
        services=[
            LUNA_FACES,
            LUNA_EVENTS,
            LUNA_PYTHON_MATCHER,
            LUNA_PYTHON_MATCHER_PROXY,
            LUNA_HANDLERS,
            LUNA_REMOTE_SDK,
        ],
        schema=schemas.DESCRIPTORS_ENCRYPTION,
        default={"enabled": False, "algorithm": "aes256-gcm", "params": {"source": "raw", "key": ""}},
        description="Descriptor encryption settings",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "EXTERNAL_LUNA_STREAMS_HLS_RETRANSMISSION_ADDRESS": BaseSettingDefinition(
        settingName="EXTERNAL_LUNA_STREAMS_HLS_RETRANSMISSION_ADDRESS",
        services=[LUNA_VIDEO_MANAGER],
        schema=schemas.RETRANSMISSION_ADDRESS_SCHEMA,
        default={"host": "http://127.0.0.1", "port": 8888},
        description="external luna streams hls retransmission address",
        groups=[GROUP_LUNA_PLATFORM],
    ),
    "LUNA_VIDEO_MANAGER_LOGS_CLEAR_INTERVAL": BaseSettingDefinition(
        settingName="LUNA_VIDEO_MANAGER_LOGS_CLEAR_INTERVAL",
        services=[LUNA_VIDEO_MANAGER],
        schema=schemas.LOGS_CLEAR_INTERVAL,
        default={"interval": 7, "interval_type": "days", "check_interval": 180, "active": True},
        description="Interval for clear logs.",
        groups=[GROUP_LUNA_PLATFORM],
    ),
}
