from abc import ABC, abstractmethod

from cow.enums.tasks import SubTaskStatus, TaskType
from luna3.client import Client

from luna_lambda_tools.private.monitoring import MonitoringPoint
from luna_lambda_tools.private.tasks_tools.base_subtask import BaseSubTask
from luna_lambda_tools.private.tasks_tools.redis_db import structs
from luna_lambda_tools.private.tasks_tools.redis_db.context import WorkerRedisContext
from luna_lambda_tools.public.exceptions import UserTaskLambdaException


class _BaseLambdaTask(BaseSubTask, ABC):
    """Lambda task class."""

    def __init__(self, redisContext: WorkerRedisContext, luna3Client: Client, app: "AppCtx"):
        super().__init__(redisContext=redisContext, luna3Client=luna3Client, loggerTitle="Lambda tasks")
        self.app = app
        self._luna3Client = luna3Client
        self._monitoringEnabled = app.serviceConfig.monitoring.sendData
        self._monitoring = app.monitoring
        self.requestId = None

    @property
    def taskType(self) -> TaskType:
        """Task type"""
        return TaskType.lambda_task

    async def splitTask2SubTasks(self, taskContentRequest: structs.TaskContentRequest) -> list[dict]:
        """Split task content to sub task contents"""
        self.accountId = taskContentRequest.accountId
        lambdaId = taskContentRequest.content["lambda_id"]
        try:
            userContentList = await self.splitTasksContent(content=taskContentRequest.content)
            for row in userContentList:
                if not isinstance(row, dict):
                    raise ValueError("Expected only dict as subtask content")
                row["lambda_id"] = lambdaId
            self.requestId = taskContentRequest.lRId.split(",")[-1]
        except UserTaskLambdaException as exc:
            return [{"lambda_id": lambdaId, "splitting_error": f"{type(exc)}: {str(exc)}"}]
        except Exception as exc:
            self.logger.exception(exc_info=True)
            return [{"lambda_id": lambdaId, "splitting_error": f"{type(exc)}: {str(exc)}"}]
        return userContentList

    async def execute(self, taskData: structs.QueueSubTask) -> tuple[str, SubTaskStatus]:
        """Execute current sub task processing"""
        self.accountId = taskData.accountId
        self.requestId = taskData.lRId.split(",")[-1]
        try:
            result = await self.executeSubtask(subtaskContent=taskData.content)
        except UserTaskLambdaException:
            raise
        except Exception:
            self.logger.exception(exc_info=True)
            raise
        if isinstance(result, dict):
            result = [result]
        resultId = await self.saveResultToImageStore(result=result, taskData=taskData)
        return resultId, SubTaskStatus.done

    @abstractmethod
    async def splitTasksContent(self, content: dict) -> list[dict]:
        """Split task content to sub task contents"""
        ...

    @abstractmethod
    async def executeSubtask(self, subtaskContent: dict) -> dict | list:
        """Execute current sub task processing"""
        ...

    def sendToMonitoring(self, points: list[MonitoringPoint]) -> None:
        """
        Send point to monitoring

        Args:
            points: points
        """
        if self._monitoringEnabled:
            self._monitoring.flushPoints(points)
